"""VDI2736PlasticMetalRateableMesh"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _504
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_VDI2736_PLASTIC_METAL_RATEABLE_MESH = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.PlasticVDI2736",
    "VDI2736PlasticMetalRateableMesh",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating.cylindrical.iso6336 import _534
    from mastapy._private.gears.rating.cylindrical import _482
    from mastapy._private.gears.rating import _378

    Self = TypeVar("Self", bound="VDI2736PlasticMetalRateableMesh")
    CastSelf = TypeVar(
        "CastSelf",
        bound="VDI2736PlasticMetalRateableMesh._Cast_VDI2736PlasticMetalRateableMesh",
    )


__docformat__ = "restructuredtext en"
__all__ = ("VDI2736PlasticMetalRateableMesh",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_VDI2736PlasticMetalRateableMesh:
    """Special nested class for casting VDI2736PlasticMetalRateableMesh to subclasses."""

    __parent__: "VDI2736PlasticMetalRateableMesh"

    @property
    def plastic_gear_vdi2736_abstract_rateable_mesh(
        self: "CastSelf",
    ) -> "_504.PlasticGearVDI2736AbstractRateableMesh":
        return self.__parent__._cast(_504.PlasticGearVDI2736AbstractRateableMesh)

    @property
    def iso6336_rateable_mesh(self: "CastSelf") -> "_534.ISO6336RateableMesh":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _534

        return self.__parent__._cast(_534.ISO6336RateableMesh)

    @property
    def cylindrical_rateable_mesh(self: "CastSelf") -> "_482.CylindricalRateableMesh":
        from mastapy._private.gears.rating.cylindrical import _482

        return self.__parent__._cast(_482.CylindricalRateableMesh)

    @property
    def rateable_mesh(self: "CastSelf") -> "_378.RateableMesh":
        from mastapy._private.gears.rating import _378

        return self.__parent__._cast(_378.RateableMesh)

    @property
    def vdi2736_plastic_metal_rateable_mesh(
        self: "CastSelf",
    ) -> "VDI2736PlasticMetalRateableMesh":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class VDI2736PlasticMetalRateableMesh(_504.PlasticGearVDI2736AbstractRateableMesh):
    """VDI2736PlasticMetalRateableMesh

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VDI2736_PLASTIC_METAL_RATEABLE_MESH

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_VDI2736PlasticMetalRateableMesh":
        """Cast to another type.

        Returns:
            _Cast_VDI2736PlasticMetalRateableMesh
        """
        return _Cast_VDI2736PlasticMetalRateableMesh(self)



"""TransientSolverOptions"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import enum_with_selected_value, overridable
from mastapy._private.nodal_analysis import _71
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_TRANSIENT_SOLVER_OPTIONS = python_net_import(
    "SMT.MastaAPI.NodalAnalysis", "TransientSolverOptions"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.nodal_analysis import _56, _86, _93

    Self = TypeVar("Self", bound="TransientSolverOptions")
    CastSelf = TypeVar(
        "CastSelf", bound="TransientSolverOptions._Cast_TransientSolverOptions"
    )


__docformat__ = "restructuredtext en"
__all__ = ("TransientSolverOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TransientSolverOptions:
    """Special nested class for casting TransientSolverOptions to subclasses."""

    __parent__: "TransientSolverOptions"

    @property
    def transient_solver_options(self: "CastSelf") -> "TransientSolverOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class TransientSolverOptions(_0.APIBase):
    """TransientSolverOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TRANSIENT_SOLVER_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def absolute_tolerance_angular_velocity_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceAngularVelocityForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_angular_velocity_for_newton_raphson.setter
    @enforce_parameter_types
    def absolute_tolerance_angular_velocity_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceAngularVelocityForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_angular_velocity_for_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceAngularVelocityForStep

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_angular_velocity_for_step.setter
    @enforce_parameter_types
    def absolute_tolerance_angular_velocity_for_step(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceAngularVelocityForStep = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_lagrange_force_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceLagrangeForceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_lagrange_force_for_newton_raphson.setter
    @enforce_parameter_types
    def absolute_tolerance_lagrange_force_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceLagrangeForceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_lagrange_moment_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceLagrangeMomentForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_lagrange_moment_for_newton_raphson.setter
    @enforce_parameter_types
    def absolute_tolerance_lagrange_moment_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceLagrangeMomentForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_simple(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceSimple

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_simple.setter
    @enforce_parameter_types
    def absolute_tolerance_simple(self: "Self", value: "float") -> None:
        self.wrapped.AbsoluteToleranceSimple = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_temperature_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceTemperatureForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_temperature_for_newton_raphson.setter
    @enforce_parameter_types
    def absolute_tolerance_temperature_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceTemperatureForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_temperature_for_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceTemperatureForStep

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_temperature_for_step.setter
    @enforce_parameter_types
    def absolute_tolerance_temperature_for_step(self: "Self", value: "float") -> None:
        self.wrapped.AbsoluteToleranceTemperatureForStep = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_translational_velocity_for_newton_raphson(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceTranslationalVelocityForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_translational_velocity_for_newton_raphson.setter
    @enforce_parameter_types
    def absolute_tolerance_translational_velocity_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceTranslationalVelocityForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def absolute_tolerance_translational_velocity_for_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AbsoluteToleranceTranslationalVelocityForStep

        if temp is None:
            return 0.0

        return temp

    @absolute_tolerance_translational_velocity_for_step.setter
    @enforce_parameter_types
    def absolute_tolerance_translational_velocity_for_step(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.AbsoluteToleranceTranslationalVelocityForStep = (
            float(value) if value is not None else 0.0
        )

    @property
    def damping_scaling_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DampingScalingFactor

        if temp is None:
            return 0.0

        return temp

    @damping_scaling_factor.setter
    @enforce_parameter_types
    def damping_scaling_factor(self: "Self", value: "float") -> None:
        self.wrapped.DampingScalingFactor = float(value) if value is not None else 0.0

    @property
    def damping_scaling_for_initial_transients(
        self: "Self",
    ) -> "_56.DampingScalingTypeForInitialTransients":
        """mastapy._private.nodal_analysis.DampingScalingTypeForInitialTransients"""
        temp = self.wrapped.DampingScalingForInitialTransients

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.DampingScalingTypeForInitialTransients"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._56",
            "DampingScalingTypeForInitialTransients",
        )(value)

    @damping_scaling_for_initial_transients.setter
    @enforce_parameter_types
    def damping_scaling_for_initial_transients(
        self: "Self", value: "_56.DampingScalingTypeForInitialTransients"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.DampingScalingTypeForInitialTransients"
        )
        self.wrapped.DampingScalingForInitialTransients = value

    @property
    def end_time(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EndTime

        if temp is None:
            return 0.0

        return temp

    @end_time.setter
    @enforce_parameter_types
    def end_time(self: "Self", value: "float") -> None:
        self.wrapped.EndTime = float(value) if value is not None else 0.0

    @property
    def integration_method(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_IntegrationMethod":
        """EnumWithSelectedValue[mastapy._private.nodal_analysis.IntegrationMethod]"""
        temp = self.wrapped.IntegrationMethod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_IntegrationMethod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @integration_method.setter
    @enforce_parameter_types
    def integration_method(self: "Self", value: "_71.IntegrationMethod") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_IntegrationMethod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.IntegrationMethod = value

    @property
    def limit_time_step_for_final_results(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.LimitTimeStepForFinalResults

        if temp is None:
            return False

        return temp

    @limit_time_step_for_final_results.setter
    @enforce_parameter_types
    def limit_time_step_for_final_results(self: "Self", value: "bool") -> None:
        self.wrapped.LimitTimeStepForFinalResults = (
            bool(value) if value is not None else False
        )

    @property
    def log_initial_transients(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.LogInitialTransients

        if temp is None:
            return False

        return temp

    @log_initial_transients.setter
    @enforce_parameter_types
    def log_initial_transients(self: "Self", value: "bool") -> None:
        self.wrapped.LogInitialTransients = bool(value) if value is not None else False

    @property
    def maximum_number_of_time_steps(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.MaximumNumberOfTimeSteps

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @maximum_number_of_time_steps.setter
    @enforce_parameter_types
    def maximum_number_of_time_steps(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.MaximumNumberOfTimeSteps = value

    @property
    def maximum_time_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaximumTimeStep

        if temp is None:
            return 0.0

        return temp

    @maximum_time_step.setter
    @enforce_parameter_types
    def maximum_time_step(self: "Self", value: "float") -> None:
        self.wrapped.MaximumTimeStep = float(value) if value is not None else 0.0

    @property
    def maximum_time_step_for_final_results(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaximumTimeStepForFinalResults

        if temp is None:
            return 0.0

        return temp

    @maximum_time_step_for_final_results.setter
    @enforce_parameter_types
    def maximum_time_step_for_final_results(self: "Self", value: "float") -> None:
        self.wrapped.MaximumTimeStepForFinalResults = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_step_between_results(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MinimumStepBetweenResults

        if temp is None:
            return 0.0

        return temp

    @minimum_step_between_results.setter
    @enforce_parameter_types
    def minimum_step_between_results(self: "Self", value: "float") -> None:
        self.wrapped.MinimumStepBetweenResults = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_time_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MinimumTimeStep

        if temp is None:
            return 0.0

        return temp

    @minimum_time_step.setter
    @enforce_parameter_types
    def minimum_time_step(self: "Self", value: "float") -> None:
        self.wrapped.MinimumTimeStep = float(value) if value is not None else 0.0

    @property
    def rayleigh_damping_alpha(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RayleighDampingAlpha

        if temp is None:
            return 0.0

        return temp

    @rayleigh_damping_alpha.setter
    @enforce_parameter_types
    def rayleigh_damping_alpha(self: "Self", value: "float") -> None:
        self.wrapped.RayleighDampingAlpha = float(value) if value is not None else 0.0

    @property
    def rayleigh_damping_beta(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RayleighDampingBeta

        if temp is None:
            return 0.0

        return temp

    @rayleigh_damping_beta.setter
    @enforce_parameter_types
    def rayleigh_damping_beta(self: "Self", value: "float") -> None:
        self.wrapped.RayleighDampingBeta = float(value) if value is not None else 0.0

    @property
    def relative_tolerance_simple(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RelativeToleranceSimple

        if temp is None:
            return 0.0

        return temp

    @relative_tolerance_simple.setter
    @enforce_parameter_types
    def relative_tolerance_simple(self: "Self", value: "float") -> None:
        self.wrapped.RelativeToleranceSimple = (
            float(value) if value is not None else 0.0
        )

    @property
    def relative_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RelativeToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @relative_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def relative_tolerance_for_newton_raphson(self: "Self", value: "float") -> None:
        self.wrapped.RelativeToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def relative_tolerance_for_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RelativeToleranceForStep

        if temp is None:
            return 0.0

        return temp

    @relative_tolerance_for_step.setter
    @enforce_parameter_types
    def relative_tolerance_for_step(self: "Self", value: "float") -> None:
        self.wrapped.RelativeToleranceForStep = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_force_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ResidualForceToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_force_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_force_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualForceToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_lagrange_angular_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ResidualLagrangeAngularToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_lagrange_angular_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_lagrange_angular_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualLagrangeAngularToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_lagrange_translational_tolerance_for_newton_raphson(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.ResidualLagrangeTranslationalToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_lagrange_translational_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_lagrange_translational_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualLagrangeTranslationalToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_moment_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ResidualMomentToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_moment_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_moment_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualMomentToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_relative_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ResidualRelativeToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_relative_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_relative_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualRelativeToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def residual_temperature_tolerance_for_newton_raphson(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ResidualTemperatureToleranceForNewtonRaphson

        if temp is None:
            return 0.0

        return temp

    @residual_temperature_tolerance_for_newton_raphson.setter
    @enforce_parameter_types
    def residual_temperature_tolerance_for_newton_raphson(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ResidualTemperatureToleranceForNewtonRaphson = (
            float(value) if value is not None else 0.0
        )

    @property
    def result_logging_frequency(self: "Self") -> "_86.ResultLoggingFrequency":
        """mastapy._private.nodal_analysis.ResultLoggingFrequency"""
        temp = self.wrapped.ResultLoggingFrequency

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.ResultLoggingFrequency"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._86", "ResultLoggingFrequency"
        )(value)

    @result_logging_frequency.setter
    @enforce_parameter_types
    def result_logging_frequency(
        self: "Self", value: "_86.ResultLoggingFrequency"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.ResultLoggingFrequency"
        )
        self.wrapped.ResultLoggingFrequency = value

    @property
    def rotate_connections_with_bodies(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.RotateConnectionsWithBodies

        if temp is None:
            return False

        return temp

    @rotate_connections_with_bodies.setter
    @enforce_parameter_types
    def rotate_connections_with_bodies(self: "Self", value: "bool") -> None:
        self.wrapped.RotateConnectionsWithBodies = (
            bool(value) if value is not None else False
        )

    @property
    def solver_tolerance_input_method(
        self: "Self",
    ) -> "_93.TransientSolverToleranceInputMethod":
        """mastapy._private.nodal_analysis.TransientSolverToleranceInputMethod"""
        temp = self.wrapped.SolverToleranceInputMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.TransientSolverToleranceInputMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._93", "TransientSolverToleranceInputMethod"
        )(value)

    @solver_tolerance_input_method.setter
    @enforce_parameter_types
    def solver_tolerance_input_method(
        self: "Self", value: "_93.TransientSolverToleranceInputMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.TransientSolverToleranceInputMethod"
        )
        self.wrapped.SolverToleranceInputMethod = value

    @property
    def theta(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.Theta

        if temp is None:
            return 0.0

        return temp

    @theta.setter
    @enforce_parameter_types
    def theta(self: "Self", value: "float") -> None:
        self.wrapped.Theta = float(value) if value is not None else 0.0

    @property
    def time_for_initial_transients(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.TimeForInitialTransients

        if temp is None:
            return 0.0

        return temp

    @time_for_initial_transients.setter
    @enforce_parameter_types
    def time_for_initial_transients(self: "Self", value: "float") -> None:
        self.wrapped.TimeForInitialTransients = (
            float(value) if value is not None else 0.0
        )

    @property
    def time_step_length(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.TimeStepLength

        if temp is None:
            return 0.0

        return temp

    @time_step_length.setter
    @enforce_parameter_types
    def time_step_length(self: "Self", value: "float") -> None:
        self.wrapped.TimeStepLength = float(value) if value is not None else 0.0

    @property
    def time_to_start_using_final_results_maximum_time_step(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.TimeToStartUsingFinalResultsMaximumTimeStep

        if temp is None:
            return 0.0

        return temp

    @time_to_start_using_final_results_maximum_time_step.setter
    @enforce_parameter_types
    def time_to_start_using_final_results_maximum_time_step(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.TimeToStartUsingFinalResultsMaximumTimeStep = (
            float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_TransientSolverOptions":
        """Cast to another type.

        Returns:
            _Cast_TransientSolverOptions
        """
        return _Cast_TransientSolverOptions(self)



"""CustomReportItemContainerCollection"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.report import _1814
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_CUSTOM_REPORT_ITEM_CONTAINER_COLLECTION = python_net_import(
    "SMT.MastaAPI.Utility.Report", "CustomReportItemContainerCollection"
)

if TYPE_CHECKING:
    from typing import Any, Type

    from mastapy._private.utility.report import _1815, _1807, _1824, _1811

    Self = TypeVar("Self", bound="CustomReportItemContainerCollection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CustomReportItemContainerCollection._Cast_CustomReportItemContainerCollection",
    )

T = TypeVar("T", bound="_1815.CustomReportItemContainerCollectionItem")

__docformat__ = "restructuredtext en"
__all__ = ("CustomReportItemContainerCollection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CustomReportItemContainerCollection:
    """Special nested class for casting CustomReportItemContainerCollection to subclasses."""

    __parent__: "CustomReportItemContainerCollection"

    @property
    def custom_report_item_container_collection_base(
        self: "CastSelf",
    ) -> "_1814.CustomReportItemContainerCollectionBase":
        return self.__parent__._cast(_1814.CustomReportItemContainerCollectionBase)

    @property
    def custom_report_item(self: "CastSelf") -> "_1811.CustomReportItem":
        from mastapy._private.utility.report import _1811

        return self.__parent__._cast(_1811.CustomReportItem)

    @property
    def custom_report_columns(self: "CastSelf") -> "_1807.CustomReportColumns":
        from mastapy._private.utility.report import _1807

        return self.__parent__._cast(_1807.CustomReportColumns)

    @property
    def custom_report_tabs(self: "CastSelf") -> "_1824.CustomReportTabs":
        from mastapy._private.utility.report import _1824

        return self.__parent__._cast(_1824.CustomReportTabs)

    @property
    def custom_report_item_container_collection(
        self: "CastSelf",
    ) -> "CustomReportItemContainerCollection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CustomReportItemContainerCollection(
    _1814.CustomReportItemContainerCollectionBase, Generic[T]
):
    """CustomReportItemContainerCollection

    This is a mastapy class.

    Generic Types:
        T
    """

    TYPE: ClassVar["Type"] = _CUSTOM_REPORT_ITEM_CONTAINER_COLLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_CustomReportItemContainerCollection":
        """Cast to another type.

        Returns:
            _Cast_CustomReportItemContainerCollection
        """
        return _Cast_CustomReportItemContainerCollection(self)



"""ISOLubricantType"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_ISO_LUBRICANT_TYPE = python_net_import("SMT.MastaAPI.Materials", "ISOLubricantType")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ISOLubricantType")
    CastSelf = TypeVar("CastSelf", bound="ISOLubricantType._Cast_ISOLubricantType")


__docformat__ = "restructuredtext en"
__all__ = ("ISOLubricantType",)


class ISOLubricantType(Enum):
    """ISOLubricantType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _ISO_LUBRICANT_TYPE

    MINERAL_OIL = 0
    WATER_SOLUBLE_POLYGLYCOL = 1
    NON_WATER_SOLUBLE_POLYGLYCOL = 2
    POLYALPHAOLEFIN = 3
    PHOSPHATE_ESTER = 4
    TRACTION_FLUID = 5


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ISOLubricantType.__setattr__ = __enum_setattr
ISOLubricantType.__delattr__ = __enum_delattr



"""ISO6336AbstractMeshSingleFlankRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.rating.cylindrical import _478
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ISO6336_ABSTRACT_MESH_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336",
    "ISO6336AbstractMeshSingleFlankRating",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.rating.cylindrical import _489
    from mastapy._private.gears.rating.cylindrical.iso6336 import (
        _528,
        _523,
        _525,
        _527,
        _531,
    )
    from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import (
        _501,
        _503,
        _505,
    )
    from mastapy._private.gears.rating.cylindrical.din3990 import _544
    from mastapy._private.gears.rating import _377

    Self = TypeVar("Self", bound="ISO6336AbstractMeshSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ISO6336AbstractMeshSingleFlankRating._Cast_ISO6336AbstractMeshSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISO6336AbstractMeshSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISO6336AbstractMeshSingleFlankRating:
    """Special nested class for casting ISO6336AbstractMeshSingleFlankRating to subclasses."""

    __parent__: "ISO6336AbstractMeshSingleFlankRating"

    @property
    def cylindrical_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_478.CylindricalMeshSingleFlankRating":
        return self.__parent__._cast(_478.CylindricalMeshSingleFlankRating)

    @property
    def mesh_single_flank_rating(self: "CastSelf") -> "_377.MeshSingleFlankRating":
        from mastapy._private.gears.rating import _377

        return self.__parent__._cast(_377.MeshSingleFlankRating)

    @property
    def metal_plastic_or_plastic_metal_vdi2736_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_501.MetalPlasticOrPlasticMetalVDI2736MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _501

        return self.__parent__._cast(
            _501.MetalPlasticOrPlasticMetalVDI2736MeshSingleFlankRating
        )

    @property
    def plastic_gear_vdi2736_abstract_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_503.PlasticGearVDI2736AbstractMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _503

        return self.__parent__._cast(
            _503.PlasticGearVDI2736AbstractMeshSingleFlankRating
        )

    @property
    def plastic_plastic_vdi2736_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_505.PlasticPlasticVDI2736MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _505

        return self.__parent__._cast(_505.PlasticPlasticVDI2736MeshSingleFlankRating)

    @property
    def iso63361996_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_523.ISO63361996MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _523

        return self.__parent__._cast(_523.ISO63361996MeshSingleFlankRating)

    @property
    def iso63362006_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_525.ISO63362006MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _525

        return self.__parent__._cast(_525.ISO63362006MeshSingleFlankRating)

    @property
    def iso63362019_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_527.ISO63362019MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _527

        return self.__parent__._cast(_527.ISO63362019MeshSingleFlankRating)

    @property
    def iso6336_abstract_metal_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_531.ISO6336AbstractMetalMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _531

        return self.__parent__._cast(_531.ISO6336AbstractMetalMeshSingleFlankRating)

    @property
    def din3990_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_544.DIN3990MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.din3990 import _544

        return self.__parent__._cast(_544.DIN3990MeshSingleFlankRating)

    @property
    def iso6336_abstract_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "ISO6336AbstractMeshSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ISO6336AbstractMeshSingleFlankRating(_478.CylindricalMeshSingleFlankRating):
    """ISO6336AbstractMeshSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO6336_ABSTRACT_MESH_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def application_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ApplicationFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_ratio_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactRatioFactorContact

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_ratio_factor_for_nominal_root_root_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactRatioFactorForNominalRootRootStress

        if temp is None:
            return 0.0

        return temp

    @property
    def dynamic_factor_source(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DynamicFactorSource

        if temp is None:
            return ""

        return temp

    @property
    def elasticity_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ElasticityFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def face_load_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceLoadFactorBending

        if temp is None:
            return 0.0

        return temp

    @property
    def face_load_factor_contact_source(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceLoadFactorContactSource

        if temp is None:
            return ""

        return temp

    @property
    def helix_angle_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HelixAngleFactorBending

        if temp is None:
            return 0.0

        return temp

    @property
    def helix_angle_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HelixAngleFactorContact

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_coefficient_of_friction_calculated_constant_flash_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.MeanCoefficientOfFrictionCalculatedConstantFlashTemperatureMethod
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def misalignment_contact_pattern_enhancement(
        self: "Self",
    ) -> "_489.MisalignmentContactPatternEnhancements":
        """mastapy._private.gears.rating.cylindrical.MisalignmentContactPatternEnhancements

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MisalignmentContactPatternEnhancement

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.MisalignmentContactPatternEnhancements",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._489",
            "MisalignmentContactPatternEnhancements",
        )(value)

    @property
    def nominal_contact_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NominalContactStress

        if temp is None:
            return 0.0

        return temp

    @property
    def sliding_velocity_at_end_of_active_profile(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SlidingVelocityAtEndOfActiveProfile

        if temp is None:
            return 0.0

        return temp

    @property
    def sliding_velocity_at_pitch_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SlidingVelocityAtPitchPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def sliding_velocity_at_start_of_active_profile(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SlidingVelocityAtStartOfActiveProfile

        if temp is None:
            return 0.0

        return temp

    @property
    def sum_of_tangential_velocities_at_end_of_active_profile(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SumOfTangentialVelocitiesAtEndOfActiveProfile

        if temp is None:
            return 0.0

        return temp

    @property
    def sum_of_tangential_velocities_at_pitch_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SumOfTangentialVelocitiesAtPitchPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def sum_of_tangential_velocities_at_start_of_active_profile(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SumOfTangentialVelocitiesAtStartOfActiveProfile

        if temp is None:
            return 0.0

        return temp

    @property
    def total_contact_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TotalContactRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_load_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseLoadFactorBending

        if temp is None:
            return 0.0

        return temp

    @property
    def zone_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ZoneFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def gear_single_flank_ratings(
        self: "Self",
    ) -> "List[_528.ISO6336AbstractGearSingleFlankRating]":
        """List[mastapy._private.gears.rating.cylindrical.iso6336.ISO6336AbstractGearSingleFlankRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearSingleFlankRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def isodin_cylindrical_gear_single_flank_ratings(
        self: "Self",
    ) -> "List[_528.ISO6336AbstractGearSingleFlankRating]":
        """List[mastapy._private.gears.rating.cylindrical.iso6336.ISO6336AbstractGearSingleFlankRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ISODINCylindricalGearSingleFlankRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ISO6336AbstractMeshSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_ISO6336AbstractMeshSingleFlankRating
        """
        return _Cast_ISO6336AbstractMeshSingleFlankRating(self)



"""AngularContactThrustBallBearing"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private.bearings.bearing_designs.rolling import _2188
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ANGULAR_CONTACT_THRUST_BALL_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Rolling", "AngularContactThrustBallBearing"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_designs.rolling import _2193, _2218
    from mastapy._private.bearings.bearing_designs import _2184, _2187, _2183

    Self = TypeVar("Self", bound="AngularContactThrustBallBearing")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AngularContactThrustBallBearing._Cast_AngularContactThrustBallBearing",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AngularContactThrustBallBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AngularContactThrustBallBearing:
    """Special nested class for casting AngularContactThrustBallBearing to subclasses."""

    __parent__: "AngularContactThrustBallBearing"

    @property
    def angular_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2188.AngularContactBallBearing":
        return self.__parent__._cast(_2188.AngularContactBallBearing)

    @property
    def ball_bearing(self: "CastSelf") -> "_2193.BallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2193

        return self.__parent__._cast(_2193.BallBearing)

    @property
    def rolling_bearing(self: "CastSelf") -> "_2218.RollingBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2218

        return self.__parent__._cast(_2218.RollingBearing)

    @property
    def detailed_bearing(self: "CastSelf") -> "_2184.DetailedBearing":
        from mastapy._private.bearings.bearing_designs import _2184

        return self.__parent__._cast(_2184.DetailedBearing)

    @property
    def non_linear_bearing(self: "CastSelf") -> "_2187.NonLinearBearing":
        from mastapy._private.bearings.bearing_designs import _2187

        return self.__parent__._cast(_2187.NonLinearBearing)

    @property
    def bearing_design(self: "CastSelf") -> "_2183.BearingDesign":
        from mastapy._private.bearings.bearing_designs import _2183

        return self.__parent__._cast(_2183.BearingDesign)

    @property
    def angular_contact_thrust_ball_bearing(
        self: "CastSelf",
    ) -> "AngularContactThrustBallBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AngularContactThrustBallBearing(_2188.AngularContactBallBearing):
    """AngularContactThrustBallBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ANGULAR_CONTACT_THRUST_BALL_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.Width

        if temp is None:
            return 0.0

        return temp

    @width.setter
    @enforce_parameter_types
    def width(self: "Self", value: "float") -> None:
        self.wrapped.Width = float(value) if value is not None else 0.0

    @property
    def cast_to(self: "Self") -> "_Cast_AngularContactThrustBallBearing":
        """Cast to another type.

        Returns:
            _Cast_AngularContactThrustBallBearing
        """
        return _Cast_AngularContactThrustBallBearing(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6011 import (
        AbstractAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6012 import (
        AbstractShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6013 import (
        AbstractShaftOrHousingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6014 import (
        AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6015 import (
        AGMAGleasonConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6016 import (
        AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6017 import (
        AGMAGleasonConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6018 import (
        AssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6019 import (
        BearingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6020 import (
        BeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6021 import (
        BeltDriveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6022 import (
        BevelDifferentialGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6023 import (
        BevelDifferentialGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6024 import (
        BevelDifferentialGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6025 import (
        BevelDifferentialPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6026 import (
        BevelDifferentialSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6027 import (
        BevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6028 import (
        BevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6029 import (
        BevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6030 import (
        BoltCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6031 import (
        BoltedJointCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6032 import (
        ClutchCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6033 import (
        ClutchConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6034 import (
        ClutchHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6035 import (
        CoaxialConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6036 import (
        ComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6037 import (
        ConceptCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6038 import (
        ConceptCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6039 import (
        ConceptCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6040 import (
        ConceptGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6041 import (
        ConceptGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6042 import (
        ConceptGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6043 import (
        ConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6044 import (
        ConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6045 import (
        ConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6046 import (
        ConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6047 import (
        ConnectorCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6048 import (
        CouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6049 import (
        CouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6050 import (
        CouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6051 import (
        CVTBeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6052 import (
        CVTCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6053 import (
        CVTPulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6054 import (
        CycloidalAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6055 import (
        CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6056 import (
        CycloidalDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6057 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6058 import (
        CylindricalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6059 import (
        CylindricalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6060 import (
        CylindricalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6061 import (
        CylindricalPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6062 import (
        DatumCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6063 import (
        ExternalCADModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6064 import (
        FaceGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6065 import (
        FaceGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6066 import (
        FaceGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6067 import (
        FEPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6068 import (
        FlexiblePinAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6069 import (
        GearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6070 import (
        GearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6071 import (
        GearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6072 import (
        GuideDxfModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6073 import (
        HypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6074 import (
        HypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6075 import (
        HypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6076 import (
        InterMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6077 import (
        KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6078 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6079 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6080 import (
        KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6081 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6082 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6083 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6084 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6085 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6086 import (
        MassDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6087 import (
        MeasurementComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6088 import (
        MicrophoneArrayCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6089 import (
        MicrophoneCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6090 import (
        MountableComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6091 import (
        OilSealCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6092 import (
        PartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6093 import (
        PartToPartShearCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6094 import (
        PartToPartShearCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6095 import (
        PartToPartShearCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6096 import (
        PlanetaryConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6097 import (
        PlanetaryGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6098 import (
        PlanetCarrierCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6099 import (
        PointLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6100 import (
        PowerLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6101 import (
        PulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6102 import (
        RingPinsCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6103 import (
        RingPinsToDiscConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6104 import (
        RollingRingAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6105 import (
        RollingRingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6106 import (
        RollingRingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6107 import (
        RootAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6108 import (
        ShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6109 import (
        ShaftHubConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6110 import (
        ShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6111 import (
        SpecialisedAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6112 import (
        SpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6113 import (
        SpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6114 import (
        SpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6115 import (
        SpringDamperCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6116 import (
        SpringDamperConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6117 import (
        SpringDamperHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6118 import (
        StraightBevelDiffGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6119 import (
        StraightBevelDiffGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6120 import (
        StraightBevelDiffGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6121 import (
        StraightBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6122 import (
        StraightBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6123 import (
        StraightBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6124 import (
        StraightBevelPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6125 import (
        StraightBevelSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6126 import (
        SynchroniserCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6127 import (
        SynchroniserHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6128 import (
        SynchroniserPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6129 import (
        SynchroniserSleeveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6130 import (
        TorqueConverterCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6131 import (
        TorqueConverterConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6132 import (
        TorqueConverterPumpCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6133 import (
        TorqueConverterTurbineCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6134 import (
        UnbalancedMassCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6135 import (
        VirtualComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6136 import (
        WormGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6137 import (
        WormGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6138 import (
        WormGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6139 import (
        ZerolBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6140 import (
        ZerolBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6141 import (
        ZerolBevelGearSetCompoundHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6011": [
            "AbstractAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6012": [
            "AbstractShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6013": [
            "AbstractShaftOrHousingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6014": [
            "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6015": [
            "AGMAGleasonConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6016": [
            "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6017": [
            "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6018": [
            "AssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6019": [
            "BearingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6020": [
            "BeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6021": [
            "BeltDriveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6022": [
            "BevelDifferentialGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6023": [
            "BevelDifferentialGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6024": [
            "BevelDifferentialGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6025": [
            "BevelDifferentialPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6026": [
            "BevelDifferentialSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6027": [
            "BevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6028": [
            "BevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6029": [
            "BevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6030": [
            "BoltCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6031": [
            "BoltedJointCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6032": [
            "ClutchCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6033": [
            "ClutchConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6034": [
            "ClutchHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6035": [
            "CoaxialConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6036": [
            "ComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6037": [
            "ConceptCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6038": [
            "ConceptCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6039": [
            "ConceptCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6040": [
            "ConceptGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6041": [
            "ConceptGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6042": [
            "ConceptGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6043": [
            "ConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6044": [
            "ConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6045": [
            "ConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6046": [
            "ConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6047": [
            "ConnectorCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6048": [
            "CouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6049": [
            "CouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6050": [
            "CouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6051": [
            "CVTBeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6052": [
            "CVTCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6053": [
            "CVTPulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6054": [
            "CycloidalAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6055": [
            "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6056": [
            "CycloidalDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6057": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6058": [
            "CylindricalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6059": [
            "CylindricalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6060": [
            "CylindricalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6061": [
            "CylindricalPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6062": [
            "DatumCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6063": [
            "ExternalCADModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6064": [
            "FaceGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6065": [
            "FaceGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6066": [
            "FaceGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6067": [
            "FEPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6068": [
            "FlexiblePinAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6069": [
            "GearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6070": [
            "GearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6071": [
            "GearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6072": [
            "GuideDxfModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6073": [
            "HypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6074": [
            "HypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6075": [
            "HypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6076": [
            "InterMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6077": [
            "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6078": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6079": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6080": [
            "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6081": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6082": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6083": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6084": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6085": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6086": [
            "MassDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6087": [
            "MeasurementComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6088": [
            "MicrophoneArrayCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6089": [
            "MicrophoneCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6090": [
            "MountableComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6091": [
            "OilSealCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6092": [
            "PartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6093": [
            "PartToPartShearCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6094": [
            "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6095": [
            "PartToPartShearCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6096": [
            "PlanetaryConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6097": [
            "PlanetaryGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6098": [
            "PlanetCarrierCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6099": [
            "PointLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6100": [
            "PowerLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6101": [
            "PulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6102": [
            "RingPinsCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6103": [
            "RingPinsToDiscConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6104": [
            "RollingRingAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6105": [
            "RollingRingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6106": [
            "RollingRingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6107": [
            "RootAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6108": [
            "ShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6109": [
            "ShaftHubConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6110": [
            "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6111": [
            "SpecialisedAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6112": [
            "SpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6113": [
            "SpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6114": [
            "SpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6115": [
            "SpringDamperCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6116": [
            "SpringDamperConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6117": [
            "SpringDamperHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6118": [
            "StraightBevelDiffGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6119": [
            "StraightBevelDiffGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6120": [
            "StraightBevelDiffGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6121": [
            "StraightBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6122": [
            "StraightBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6123": [
            "StraightBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6124": [
            "StraightBevelPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6125": [
            "StraightBevelSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6126": [
            "SynchroniserCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6127": [
            "SynchroniserHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6128": [
            "SynchroniserPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6129": [
            "SynchroniserSleeveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6130": [
            "TorqueConverterCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6131": [
            "TorqueConverterConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6132": [
            "TorqueConverterPumpCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6133": [
            "TorqueConverterTurbineCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6134": [
            "UnbalancedMassCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6135": [
            "VirtualComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6136": [
            "WormGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6137": [
            "WormGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6138": [
            "WormGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6139": [
            "ZerolBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6140": [
            "ZerolBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6141": [
            "ZerolBevelGearSetCompoundHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundHarmonicAnalysis",
    "AbstractShaftCompoundHarmonicAnalysis",
    "AbstractShaftOrHousingCompoundHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis",
    "AssemblyCompoundHarmonicAnalysis",
    "BearingCompoundHarmonicAnalysis",
    "BeltConnectionCompoundHarmonicAnalysis",
    "BeltDriveCompoundHarmonicAnalysis",
    "BevelDifferentialGearCompoundHarmonicAnalysis",
    "BevelDifferentialGearMeshCompoundHarmonicAnalysis",
    "BevelDifferentialGearSetCompoundHarmonicAnalysis",
    "BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
    "BevelDifferentialSunGearCompoundHarmonicAnalysis",
    "BevelGearCompoundHarmonicAnalysis",
    "BevelGearMeshCompoundHarmonicAnalysis",
    "BevelGearSetCompoundHarmonicAnalysis",
    "BoltCompoundHarmonicAnalysis",
    "BoltedJointCompoundHarmonicAnalysis",
    "ClutchCompoundHarmonicAnalysis",
    "ClutchConnectionCompoundHarmonicAnalysis",
    "ClutchHalfCompoundHarmonicAnalysis",
    "CoaxialConnectionCompoundHarmonicAnalysis",
    "ComponentCompoundHarmonicAnalysis",
    "ConceptCouplingCompoundHarmonicAnalysis",
    "ConceptCouplingConnectionCompoundHarmonicAnalysis",
    "ConceptCouplingHalfCompoundHarmonicAnalysis",
    "ConceptGearCompoundHarmonicAnalysis",
    "ConceptGearMeshCompoundHarmonicAnalysis",
    "ConceptGearSetCompoundHarmonicAnalysis",
    "ConicalGearCompoundHarmonicAnalysis",
    "ConicalGearMeshCompoundHarmonicAnalysis",
    "ConicalGearSetCompoundHarmonicAnalysis",
    "ConnectionCompoundHarmonicAnalysis",
    "ConnectorCompoundHarmonicAnalysis",
    "CouplingCompoundHarmonicAnalysis",
    "CouplingConnectionCompoundHarmonicAnalysis",
    "CouplingHalfCompoundHarmonicAnalysis",
    "CVTBeltConnectionCompoundHarmonicAnalysis",
    "CVTCompoundHarmonicAnalysis",
    "CVTPulleyCompoundHarmonicAnalysis",
    "CycloidalAssemblyCompoundHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis",
    "CycloidalDiscCompoundHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis",
    "CylindricalGearCompoundHarmonicAnalysis",
    "CylindricalGearMeshCompoundHarmonicAnalysis",
    "CylindricalGearSetCompoundHarmonicAnalysis",
    "CylindricalPlanetGearCompoundHarmonicAnalysis",
    "DatumCompoundHarmonicAnalysis",
    "ExternalCADModelCompoundHarmonicAnalysis",
    "FaceGearCompoundHarmonicAnalysis",
    "FaceGearMeshCompoundHarmonicAnalysis",
    "FaceGearSetCompoundHarmonicAnalysis",
    "FEPartCompoundHarmonicAnalysis",
    "FlexiblePinAssemblyCompoundHarmonicAnalysis",
    "GearCompoundHarmonicAnalysis",
    "GearMeshCompoundHarmonicAnalysis",
    "GearSetCompoundHarmonicAnalysis",
    "GuideDxfModelCompoundHarmonicAnalysis",
    "HypoidGearCompoundHarmonicAnalysis",
    "HypoidGearMeshCompoundHarmonicAnalysis",
    "HypoidGearSetCompoundHarmonicAnalysis",
    "InterMountableComponentConnectionCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis",
    "MassDiscCompoundHarmonicAnalysis",
    "MeasurementComponentCompoundHarmonicAnalysis",
    "MicrophoneArrayCompoundHarmonicAnalysis",
    "MicrophoneCompoundHarmonicAnalysis",
    "MountableComponentCompoundHarmonicAnalysis",
    "OilSealCompoundHarmonicAnalysis",
    "PartCompoundHarmonicAnalysis",
    "PartToPartShearCouplingCompoundHarmonicAnalysis",
    "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis",
    "PartToPartShearCouplingHalfCompoundHarmonicAnalysis",
    "PlanetaryConnectionCompoundHarmonicAnalysis",
    "PlanetaryGearSetCompoundHarmonicAnalysis",
    "PlanetCarrierCompoundHarmonicAnalysis",
    "PointLoadCompoundHarmonicAnalysis",
    "PowerLoadCompoundHarmonicAnalysis",
    "PulleyCompoundHarmonicAnalysis",
    "RingPinsCompoundHarmonicAnalysis",
    "RingPinsToDiscConnectionCompoundHarmonicAnalysis",
    "RollingRingAssemblyCompoundHarmonicAnalysis",
    "RollingRingCompoundHarmonicAnalysis",
    "RollingRingConnectionCompoundHarmonicAnalysis",
    "RootAssemblyCompoundHarmonicAnalysis",
    "ShaftCompoundHarmonicAnalysis",
    "ShaftHubConnectionCompoundHarmonicAnalysis",
    "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "SpecialisedAssemblyCompoundHarmonicAnalysis",
    "SpiralBevelGearCompoundHarmonicAnalysis",
    "SpiralBevelGearMeshCompoundHarmonicAnalysis",
    "SpiralBevelGearSetCompoundHarmonicAnalysis",
    "SpringDamperCompoundHarmonicAnalysis",
    "SpringDamperConnectionCompoundHarmonicAnalysis",
    "SpringDamperHalfCompoundHarmonicAnalysis",
    "StraightBevelDiffGearCompoundHarmonicAnalysis",
    "StraightBevelDiffGearMeshCompoundHarmonicAnalysis",
    "StraightBevelDiffGearSetCompoundHarmonicAnalysis",
    "StraightBevelGearCompoundHarmonicAnalysis",
    "StraightBevelGearMeshCompoundHarmonicAnalysis",
    "StraightBevelGearSetCompoundHarmonicAnalysis",
    "StraightBevelPlanetGearCompoundHarmonicAnalysis",
    "StraightBevelSunGearCompoundHarmonicAnalysis",
    "SynchroniserCompoundHarmonicAnalysis",
    "SynchroniserHalfCompoundHarmonicAnalysis",
    "SynchroniserPartCompoundHarmonicAnalysis",
    "SynchroniserSleeveCompoundHarmonicAnalysis",
    "TorqueConverterCompoundHarmonicAnalysis",
    "TorqueConverterConnectionCompoundHarmonicAnalysis",
    "TorqueConverterPumpCompoundHarmonicAnalysis",
    "TorqueConverterTurbineCompoundHarmonicAnalysis",
    "UnbalancedMassCompoundHarmonicAnalysis",
    "VirtualComponentCompoundHarmonicAnalysis",
    "WormGearCompoundHarmonicAnalysis",
    "WormGearMeshCompoundHarmonicAnalysis",
    "WormGearSetCompoundHarmonicAnalysis",
    "ZerolBevelGearCompoundHarmonicAnalysis",
    "ZerolBevelGearMeshCompoundHarmonicAnalysis",
    "ZerolBevelGearSetCompoundHarmonicAnalysis",
)



"""ISO153122018Results"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ISO153122018_RESULTS = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling", "ISO153122018Results"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ISO153122018Results")
    CastSelf = TypeVar(
        "CastSelf", bound="ISO153122018Results._Cast_ISO153122018Results"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISO153122018Results",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISO153122018Results:
    """Special nested class for casting ISO153122018Results to subclasses."""

    __parent__: "ISO153122018Results"

    @property
    def iso153122018_results(self: "CastSelf") -> "ISO153122018Results":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ISO153122018Results(_0.APIBase):
    """ISO153122018Results

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO153122018_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def coefficient_for_the_load_dependent_friction_moment_for_the_reference_conditions(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.CoefficientForTheLoadDependentFrictionMomentForTheReferenceConditions
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def coefficient_for_the_load_independent_friction_moment_for_the_reference_conditions(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.CoefficientForTheLoadIndependentFrictionMomentForTheReferenceConditions
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def heat_emitting_reference_surface_area(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HeatEmittingReferenceSurfaceArea

        if temp is None:
            return 0.0

        return temp

    @property
    def load_dependent_frictional_moment_under_reference_conditions_at_the_thermal_speed_rating(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.LoadDependentFrictionalMomentUnderReferenceConditionsAtTheThermalSpeedRating
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def load_independent_frictional_moment_under_reference_conditions_at_the_thermal_speed_rating(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.LoadIndependentFrictionalMomentUnderReferenceConditionsAtTheThermalSpeedRating
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def power_loss_under_reference_conditions_at_the_thermal_speed_rating(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLossUnderReferenceConditionsAtTheThermalSpeedRating

        if temp is None:
            return 0.0

        return temp

    @property
    def reason_for_invalidity(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReasonForInvalidity

        if temp is None:
            return ""

        return temp

    @property
    def reference_heat_flow(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReferenceHeatFlow

        if temp is None:
            return 0.0

        return temp

    @property
    def reference_heat_flow_density(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReferenceHeatFlowDensity

        if temp is None:
            return 0.0

        return temp

    @property
    def reference_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReferenceLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def thermal_speed_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ThermalSpeedRating

        if temp is None:
            return 0.0

        return temp

    @property
    def viscosity_of_reference_oil(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ViscosityOfReferenceOil

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_ISO153122018Results":
        """Cast to another type.

        Returns:
            _Cast_ISO153122018Results
        """
        return _Cast_ISO153122018Results(self)



"""BaseGeometryModellerDimension"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_BASE_GEOMETRY_MODELLER_DIMENSION = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.GeometryModellerLink", "BaseGeometryModellerDimension"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.geometry_modeller_link import (
        _160,
        _161,
        _166,
        _168,
    )

    Self = TypeVar("Self", bound="BaseGeometryModellerDimension")
    CastSelf = TypeVar(
        "CastSelf",
        bound="BaseGeometryModellerDimension._Cast_BaseGeometryModellerDimension",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BaseGeometryModellerDimension",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BaseGeometryModellerDimension:
    """Special nested class for casting BaseGeometryModellerDimension to subclasses."""

    __parent__: "BaseGeometryModellerDimension"

    @property
    def geometry_modeller_angle_dimension(
        self: "CastSelf",
    ) -> "_160.GeometryModellerAngleDimension":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _160

        return self.__parent__._cast(_160.GeometryModellerAngleDimension)

    @property
    def geometry_modeller_count_dimension(
        self: "CastSelf",
    ) -> "_161.GeometryModellerCountDimension":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _161

        return self.__parent__._cast(_161.GeometryModellerCountDimension)

    @property
    def geometry_modeller_length_dimension(
        self: "CastSelf",
    ) -> "_166.GeometryModellerLengthDimension":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _166

        return self.__parent__._cast(_166.GeometryModellerLengthDimension)

    @property
    def geometry_modeller_unitless_dimension(
        self: "CastSelf",
    ) -> "_168.GeometryModellerUnitlessDimension":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _168

        return self.__parent__._cast(_168.GeometryModellerUnitlessDimension)

    @property
    def base_geometry_modeller_dimension(
        self: "CastSelf",
    ) -> "BaseGeometryModellerDimension":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class BaseGeometryModellerDimension(_0.APIBase):
    """BaseGeometryModellerDimension

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BASE_GEOMETRY_MODELLER_DIMENSION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_BaseGeometryModellerDimension":
        """Cast to another type.

        Returns:
            _Cast_BaseGeometryModellerDimension
        """
        return _Cast_BaseGeometryModellerDimension(self)



"""AssemblyPowerFlow"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.power_flows import _4135
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ASSEMBLY_POWER_FLOW = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows", "AssemblyPowerFlow"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model import _2487
    from mastapy._private.system_model.analyses_and_results.static_loads import _6965
    from mastapy._private.gears.analysis import _1265
    from mastapy._private.system_model.analyses_and_results.power_flows import (
        _4143,
        _4145,
        _4148,
        _4154,
        _4155,
        _4176,
        _4158,
        _4163,
        _4166,
        _4178,
        _4181,
        _4185,
        _4194,
        _4191,
        _4195,
        _4202,
        _4209,
        _4212,
        _4198,
        _4213,
        _4214,
        _4216,
        _4218,
        _4222,
        _4225,
        _4226,
        _4229,
        _4231,
        _4233,
        _4237,
        _4238,
        _4243,
        _4246,
        _4249,
        _4252,
        _4257,
        _4261,
        _4264,
        _4268,
        _4271,
        _4236,
        _4219,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="AssemblyPowerFlow")
    CastSelf = TypeVar("CastSelf", bound="AssemblyPowerFlow._Cast_AssemblyPowerFlow")


__docformat__ = "restructuredtext en"
__all__ = ("AssemblyPowerFlow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AssemblyPowerFlow:
    """Special nested class for casting AssemblyPowerFlow to subclasses."""

    __parent__: "AssemblyPowerFlow"

    @property
    def abstract_assembly_power_flow(
        self: "CastSelf",
    ) -> "_4135.AbstractAssemblyPowerFlow":
        return self.__parent__._cast(_4135.AbstractAssemblyPowerFlow)

    @property
    def part_power_flow(self: "CastSelf") -> "_4219.PartPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4219

        return self.__parent__._cast(_4219.PartPowerFlow)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def root_assembly_power_flow(self: "CastSelf") -> "_4236.RootAssemblyPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4236

        return self.__parent__._cast(_4236.RootAssemblyPowerFlow)

    @property
    def assembly_power_flow(self: "CastSelf") -> "AssemblyPowerFlow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AssemblyPowerFlow(_4135.AbstractAssemblyPowerFlow):
    """AssemblyPowerFlow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ASSEMBLY_POWER_FLOW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def assembly_design(self: "Self") -> "_2487.Assembly":
        """mastapy._private.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_load_case(self: "Self") -> "_6965.AssemblyLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.AssemblyLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rating_for_all_gear_sets(self: "Self") -> "_1265.GearSetGroupDutyCycle":
        """mastapy._private.gears.analysis.GearSetGroupDutyCycle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RatingForAllGearSets

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def bearings(self: "Self") -> "List[_4143.BearingPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.BearingPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bearings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def belt_drives(self: "Self") -> "List[_4145.BeltDrivePowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.BeltDrivePowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltDrives

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bevel_differential_gear_sets(
        self: "Self",
    ) -> "List[_4148.BevelDifferentialGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.BevelDifferentialGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BevelDifferentialGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolted_joints(self: "Self") -> "List[_4154.BoltedJointPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.BoltedJointPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BoltedJoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolts(self: "Self") -> "List[_4155.BoltPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.BoltPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bolts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cv_ts(self: "Self") -> "List[_4176.CVTPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.CVTPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CVTs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def clutches(self: "Self") -> "List[_4158.ClutchPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ClutchPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Clutches

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_couplings(self: "Self") -> "List[_4163.ConceptCouplingPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ConceptCouplingPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_gear_sets(self: "Self") -> "List[_4166.ConceptGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ConceptGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_assemblies(self: "Self") -> "List[_4178.CycloidalAssemblyPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.CycloidalAssemblyPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_discs(self: "Self") -> "List[_4181.CycloidalDiscPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.CycloidalDiscPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gear_sets(
        self: "Self",
    ) -> "List[_4185.CylindricalGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.CylindricalGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def fe_parts(self: "Self") -> "List[_4194.FEPartPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.FEPartPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEParts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def face_gear_sets(self: "Self") -> "List[_4191.FaceGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.FaceGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def flexible_pin_assemblies(
        self: "Self",
    ) -> "List[_4195.FlexiblePinAssemblyPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.FlexiblePinAssemblyPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FlexiblePinAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def hypoid_gear_sets(self: "Self") -> "List[_4202.HypoidGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.HypoidGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(
        self: "Self",
    ) -> "List[_4209.KlingelnbergCycloPalloidHypoidGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.KlingelnbergCycloPalloidHypoidGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidHypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4212.KlingelnbergCycloPalloidSpiralBevelGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.KlingelnbergCycloPalloidSpiralBevelGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def loaded_gear_sets(self: "Self") -> "List[_4198.GearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.GearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadedGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def mass_discs(self: "Self") -> "List[_4213.MassDiscPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.MassDiscPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def measurement_components(
        self: "Self",
    ) -> "List[_4214.MeasurementComponentPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.MeasurementComponentPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeasurementComponents

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def microphones(self: "Self") -> "List[_4216.MicrophonePowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.MicrophonePowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Microphones

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def oil_seals(self: "Self") -> "List[_4218.OilSealPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.OilSealPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OilSeals

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def part_to_part_shear_couplings(
        self: "Self",
    ) -> "List[_4222.PartToPartShearCouplingPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.PartToPartShearCouplingPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PartToPartShearCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planet_carriers(self: "Self") -> "List[_4225.PlanetCarrierPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.PlanetCarrierPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PlanetCarriers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def point_loads(self: "Self") -> "List[_4226.PointLoadPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.PointLoadPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PointLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def power_loads(self: "Self") -> "List[_4229.PowerLoadPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.PowerLoadPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def ring_pins(self: "Self") -> "List[_4231.RingPinsPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.RingPinsPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RingPins

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def rolling_ring_assemblies(
        self: "Self",
    ) -> "List[_4233.RollingRingAssemblyPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.RollingRingAssemblyPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollingRingAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shaft_hub_connections(
        self: "Self",
    ) -> "List[_4237.ShaftHubConnectionPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ShaftHubConnectionPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftHubConnections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts(self: "Self") -> "List[_4238.ShaftPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ShaftPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Shafts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4243.SpiralBevelGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.SpiralBevelGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spring_dampers(self: "Self") -> "List[_4246.SpringDamperPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.SpringDamperPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpringDampers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_diff_gear_sets(
        self: "Self",
    ) -> "List[_4249.StraightBevelDiffGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.StraightBevelDiffGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelDiffGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4252.StraightBevelGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.StraightBevelGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def synchronisers(self: "Self") -> "List[_4257.SynchroniserPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.SynchroniserPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Synchronisers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def torque_converters(self: "Self") -> "List[_4261.TorqueConverterPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.TorqueConverterPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueConverters

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def unbalanced_masses(self: "Self") -> "List[_4264.UnbalancedMassPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.UnbalancedMassPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UnbalancedMasses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_sets(self: "Self") -> "List[_4268.WormGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.WormGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def zerol_bevel_gear_sets(self: "Self") -> "List[_4271.ZerolBevelGearSetPowerFlow]":
        """List[mastapy._private.system_model.analyses_and_results.power_flows.ZerolBevelGearSetPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ZerolBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AssemblyPowerFlow":
        """Cast to another type.

        Returns:
            _Cast_AssemblyPowerFlow
        """
        return _Cast_AssemblyPowerFlow(self)



"""SplineDesignTypes"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_SPLINE_DESIGN_TYPES = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines", "SplineDesignTypes"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="SplineDesignTypes")
    CastSelf = TypeVar("CastSelf", bound="SplineDesignTypes._Cast_SplineDesignTypes")


__docformat__ = "restructuredtext en"
__all__ = ("SplineDesignTypes",)


class SplineDesignTypes(Enum):
    """SplineDesignTypes

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _SPLINE_DESIGN_TYPES

    DIN_548012006 = 0
    ISO_4156122005 = 1
    GBT_347812008 = 2
    JIS_B_16032001 = 3
    SAE_B9211996 = 4
    CUSTOM = 5


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


SplineDesignTypes.__setattr__ = __enum_setattr
SplineDesignTypes.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.manufacturing.cylindrical.process_simulation._662 import (
        CutterProcessSimulation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.process_simulation._663 import (
        FormWheelGrindingProcessSimulation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.process_simulation._664 import (
        ShapingProcessSimulation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.manufacturing.cylindrical.process_simulation._662": [
            "CutterProcessSimulation"
        ],
        "_private.gears.manufacturing.cylindrical.process_simulation._663": [
            "FormWheelGrindingProcessSimulation"
        ],
        "_private.gears.manufacturing.cylindrical.process_simulation._664": [
            "ShapingProcessSimulation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CutterProcessSimulation",
    "FormWheelGrindingProcessSimulation",
    "ShapingProcessSimulation",
)



"""ResidualStressCalculationMethod"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_RESIDUAL_STRESS_CALCULATION_METHOD = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "ResidualStressCalculationMethod"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ResidualStressCalculationMethod")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ResidualStressCalculationMethod._Cast_ResidualStressCalculationMethod",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ResidualStressCalculationMethod",)


class ResidualStressCalculationMethod(Enum):
    """ResidualStressCalculationMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _RESIDUAL_STRESS_CALCULATION_METHOD

    MACKALDENER = 0
    LANG = 1
    MULLER_ET_AL = 2
    USERSPECIFIED = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ResidualStressCalculationMethod.__setattr__ = __enum_setattr
ResidualStressCalculationMethod.__delattr__ = __enum_delattr
